@@ -83,7 +83,7 @@ def calender2_make_image(diary, date)
 	image_url = (@calendar2_imageex_yearlydir == 0 ? @calendar2_image_url : %Q|#{@calendar2_image_url}/#{date[0,4]}|)
 
 	f_list = Dir.glob(%Q|#{image_dir}/#{date}_#{$1}*|.untaint)
-	if f_list[0] != nil
+	if f_list[0]
 		file = File.basename(f_list[0])
 		file = %Q|s#{file}| if File.exist?(%Q|#{image_dir}/s#{file}|.untaint)
 		%Q|<img src="#{image_url}/#{file}">|
