@@ -1,3 +1,4 @@
+# -*- coding: utf-8 -*-
 =begin
 = 本日のリンク元もうちょっとだけ強化プラグイン((-$Id: disp_referrer.rb,v 1.70 2008-03-02 09:01:45 kazuhiko Exp $-))
 
@@ -342,8 +343,12 @@ class DispRef2String
 		def self::unescape( str )
 			if str then
 				# escape ruby 1.6 bug.
-				str.gsub( /\+/, ' ').gsub(/((?:%[0-9a-fA-F]{2})+)/n) do
-					[$1.delete('%')].pack('H*')
+				begin
+					str.gsub( /\+/, ' ').gsub(/((?:%[0-9a-fA-F]{2})+)/n) do
+						[$1.delete('%')].pack('H*')
+					end
+				rescue Encoding::CompatibilityError
+					''
 				end
 			else
 				''
@@ -1014,25 +1019,28 @@ class DispRef2Refs
 			end
 			result << '<ul>'
 			@refs[cat_key].each do |a|
-				if a[2].size == 1 then
-					result << %Q[<li><a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[2][0][1].title )}</a> &times;#{a[0]}</li>\n]
-				elsif not a[2][0][1].title_ignored then
-					result << %Q[<li><a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[1] )}</a> &times;#{a[0]} : #{a[2][0][0]}]
-					a[2][1..-1].each do |b|
-						title = (b[1].title != a[1]) ? %Q[ title="#{DispRef2String::escapeHTML( b[1].title )}"] : ''
-						result << %Q[, <a rel="nofollow" href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
+				begin
+					if a[2].size == 1 then
+						result << %Q[<li><a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[2][0][1].title )}</a> &times;#{a[0]}</li>\n]
+					elsif not a[2][0][1].title_ignored then
+						result << %Q[<li><a rel="nofollow" href="#{DispRef2String::escapeHTML( a[2][0][1].url )}">#{DispRef2String::escapeHTML( a[1] )}</a> &times;#{a[0]} : #{a[2][0][0]}]
+						a[2][1..-1].each do |b|
+							title = (b[1].title != a[1]) ? %Q[ title="#{DispRef2String::escapeHTML( b[1].title )}"] : ''
+							result << %Q[, <a rel="nofollow" href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
+						end
+						result << "</li>\n"
+					else
+						result << %Q[<li>#{DispRef2String::escapeHTML( a[1] )} &times;#{a[0]} : ]
+						comma = nil
+						a[2][0..-1].each do |b|
+							title = (b[1].title != a[1]) ? %Q[ title="#{DispRef2String::escapeHTML( b[1].title )}"] : ''
+							result << comma if comma
+							result << %Q[<a rel="nofollow" href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
+							comma = ', '
+						end
+						result << "</li>\n"
 					end
-					result << "</li>\n"
-				else
-					result << %Q[<li>#{DispRef2String::escapeHTML( a[1] )} &times;#{a[0]} : ]
-					comma = nil
-					a[2][0..-1].each do |b|
-						title = (b[1].title != a[1]) ? %Q[ title="#{DispRef2String::escapeHTML( b[1].title )}"] : ''
-						result << comma if comma
-						result << %Q[<a rel="nofollow" href="#{DispRef2String::escapeHTML( b[1].url )}"#{title}>#{b[0]}</a>]
-						comma = ', '
-					end
-					result << "</li>\n"
+				rescue Encoding::CompatibilityError => e
 				end
 			end
 			result << "</ul>\n"
