@@ -172,7 +172,7 @@ module RD
 
 	class RDInlineParser
 		def on_error(et, ev, values)
-			lines_of_rest = @src.rest.to_a.length
+			lines_of_rest = @src.rest.lines.to_a.length
 			prev_words = prev_words_on_error(ev)
 			at = 4 + prev_words.length
 			message = <<-MSG
@@ -325,7 +325,7 @@ module TDiary
 	
 		def append( body, author = nil )
 			section = nil
-			body.each do |l|
+			body.lines.each do |l|
 				case l
 				when /^=(begin|end)\b/
 				  	# do nothing
@@ -368,7 +368,7 @@ module TDiary
 			r
 		end
 	
-		def to_html( opt, mode = :HTML )
+		def to_html( opt = {}, mode = :HTML )
 			r = ''
 			idx = 1
 			each_section do |section|
@@ -384,8 +384,6 @@ module TDiary
 	end
 end
 
-
-
 # Local Variables:
 # mode: ruby
 # indent-tabs-mode: t
