@@ -1,6 +1,6 @@
-# -*- coding: utf-8; -*-
+# -*- coding: utf-8 -*-
 #
-# 00default.rb: default plugins 
+# 00default.rb: default plugins
 #
 # Copyright (C) 2010, TADA Tadashi <t@tdtds.jp>
 # You can redistribute it and/or modify it under GPL2.
@@ -215,6 +215,7 @@ add_header_proc do
 	#{icon_tag}
 	#{description_tag}
 	#{jquery_tag.chomp}
+	#{script_tag.chomp}
 	#{css_tag.chomp}
 	#{iphone_tag.chomp}
 	#{title_tag.chomp}
@@ -249,6 +250,8 @@ def calc_links
 		days.sort!
 		days.unshift(nil).push(nil)
 		@navi_user_days = days[days.index(today) - 1, 3]
+		@prev_day = @navi_user_days[0]
+		@next_day = @navi_user_days[2]
 	elsif @mode == 'nyear'
 		y = 2000 # specify leam year
 		m, d = @cgi.params['date'][0].scan(/^(\d\d)(\d\d)$/)[0]
@@ -350,14 +353,40 @@ def description_tag
 end
 
 def jquery_tag
-	if /^(form|edit|preview|showcomment|conf|saveconf)$/ =~ @mode then
-		%Q[<script src="http://ajax.googleapis.com/ajax/libs/jquery/1.4/jquery.js" type="text/javascript"></script>\n\t<script src="js/00default.js" type="text/javascript"></script>]
-	else
-		''
-	end
+	%Q[<script src="http://ajax.googleapis.com/ajax/libs/jquery/1.7/jquery.min.js" type="text/javascript"></script>]
 end
 
-def theme_url; 'theme'; end
+enable_js( '00default.js' )
+add_js_setting( '$tDiary.style', "'#{@conf.style.downcase.sub( /\Ablog/, '' )}'" )
+
+if /^form|edit|preview|showcomment/ =~ @mode
+	enable_js( '02edit.js' )
+end
+
+def script_tag_query_string
+	"?#{TDIARY_VERSION}#{Time::now.strftime('%Y%m%d')}"
+end
+
+def js_url
+	defined?(Rack) ? 'assets' : 'js'
+end
+
+def script_tag
+	query = script_tag_query_string
+	html = @javascripts.sort.map {|script|
+		%Q|<script src="#{js_url}/#{script}#{query}" type="text/javascript"></script>|
+	}.join( "\n\t" )
+	html << "\n" << <<-HEAD
+		<script type="text/javascript"><!--
+		#{@javascript_setting.map{|a| "#{a[0]} = #{a[1]};"}.join("\n\t\t")}
+		//-->
+		</script>
+	HEAD
+end
+
+def theme_url
+	defined?(Rack) ? 'assets' : 'theme'
+end
 
 def css_tag
 	if @mode =~ /conf$/ then
@@ -486,7 +515,7 @@ def subtitle_link( date, index, subtitle )
 			r << "<a "
 			r << %Q[name="p#{'%02d' % index}" ] if @anchor_name
 			param = "#{date.strftime( '%Y%m%d' )}#p#{'%02d' % index}"
-			titleattr = (not subtitle or subtitle.empty?) ? '' : %Q[ title="#{remove_tag( subtitle ).gsub( /"/, "&quot;" )}"]
+			titleattr = (not subtitle or subtitle.empty?) ? '' : %Q[ title="#{remove_tag( apply_plugin subtitle ).gsub( /"/, "&quot;" )}"]
 			r << %Q[href="#{h @index}#{anchor param}"#{titleattr}>#{@conf.section_anchor}</a> ]
 		end
 
@@ -732,6 +761,9 @@ def brl; '<br clear="left">';  end
 #
 # preferences (saving methods)
 #
+if @mode =~ /conf|saveconf/
+	enable_js( '01conf.js' )
+end
 
 # basic (default)
 def saveconf_default
@@ -744,14 +776,16 @@ def saveconf_default
 		@conf.icon = @cgi.params['icon'][0]
 		@conf.banner = @cgi.params['banner'][0]
 		@conf['base_url'] = @cgi.params['base_url'][0]
+		@conf.x_frame_options = @cgi.params['x_frame_options'][0]
+		@conf.x_frame_options = nil if @conf.x_frame_options.empty?
 	end
 end
 
 # header/footer (header)
 def saveconf_header
 	if @mode == 'saveconf' then
-		@conf.header = @conf.to_native( @cgi.params['header'][0] ).gsub( /\r\n/, "\n" ).gsub( /\r/, '' ).sub( /\n+\z/, '' )
-		@conf.footer = @conf.to_native( @cgi.params['footer'][0] ).gsub( /\r\n/, "\n" ).gsub( /\r/, '' ).sub( /\n+\z/, '' )
+		@conf.header = @conf.to_native( @cgi.params['header'][0] ).lines.map{|s| s.chomp}.join( "\n" ).sub( /\n+\z/, '' )
+		@conf.footer = @conf.to_native( @cgi.params['footer'][0] ).lines.map{|s| s.chomp}.join( "\n" ).sub( /\n+\z/, '' )
 	end
 end
 
@@ -859,7 +893,11 @@ def saveconf_csrf_protection
 			err = :param
 		end
 		err = :param if check_method == 0
-		check_key = @cgi.params['key'][0]
+		check_key = ''
+		key_seed = '0123456789abcdefghijklmnopqrstuvwxyzABCDEFGHIJKLMNOPQRSTUVWXYZ'
+		1.upto(30) do
+			check_key << key_seed[rand( key_seed.length )]
+		end
 
 		if check_method & 2 != 0 && (!check_key || check_key == '') then
 			err ||= :key
