@@ -146,6 +146,7 @@ def category_anchor(c); "[#{c}]"; end
 #
 # preferences (resources)
 #
+@conf_saving = '保存中……'
 
 # genre labels
 @conf_genre_label['basic'] = '基本'
@@ -195,6 +196,14 @@ add_conf_proc( 'default', 'サイトの情報', 'basic' ) do
 	<h3 class="subtitle">バナー画像</h3>
 	#{"<p>この日記を表す画像(バナー)があればそのURLを指定します。makerssプラグインなどでRSSを出力する場合などに使われます。何も入力しなくてもかまいません。</p>" unless @conf.mobile_agent?}
 	<p><input name="banner" value="#{h @conf.banner}" size="70"></p>
+
+	<h3 class="subtitle">フレーム内表示</h3>
+	#{"<p>日記全体をフレーム内にくるんで表示することを許可します。</p>" unless @conf.mobile_agent?}
+	<p><select name="x_frame_options">
+		<option value=""#{" selected" unless @conf.x_frame_options}>許可する</option>
+		<option value="SAMEORIGIN"#{" selected" if @conf.x_frame_options == 'SAMEORIGIN'}>同一ドメインなら許可する</option>
+		<option value="DENY"#{" selected" if @conf.x_frame_options == 'DENY'}>禁止する</option>
+	</select></p>
 	HTML
 end
 
@@ -343,16 +352,11 @@ add_conf_proc( 'csrf_protection', 'CSRF(乗っ取り)対策', 'security' ) do
 	#{"<p>書き込みフォームに偽装書き込み防止のためのキーを設定し、CSRFを防ぎます。
 	偽ページが秘密のキーを知らない限り、
 	偽の書き込み要求を生成することができなくなります。
-	この検査を「する」に設定する場合、次の鍵も設定して下さい。
+	この検査を「する」にすると、システムが鍵を自動的に生成、設定します。
 	上の設定と両方「しない」にすることはできません。</p>
 	<p>この設定を「する」にした場合、この機構に対応していない一部の
 	プラグインが動作しなくなることがあります。</p>
 	" unless @conf.mobile_agent?}
-	<h4>CSRF 防止キー</h4>
-	<p><input type="text" name="key" value="#{h csrf_protection_key}" size="30"></p>
-	#{"<p>偽装防止キーを設定します。推測しにくい適当な文字列を指定して下さい。
-	この鍵が外部に洩れると、CSRF攻撃を受ける可能性があります。
-	他のパスワードと共用はしてはいけません。なお、設定した文字列をあなたが覚えておく必要はありません。</p>" unless @conf.mobile_agent?}
 	#{"<p class=\"message\">注意:
 	あなたのブラウザは現在Refererを送出していないようです。
 	<a href=\"#{h @update}?conf=csrf_protection\">このリンクからもう一回
@@ -376,7 +380,7 @@ add_conf_proc( 'logger', 'ログレベル選択', 'basic' ) do
 	r << conf_logger_list
 end
 
-add_conf_proc( 'suggestfilter', 'おすすめフィルタ', 'basic' ) do
+add_conf_proc( 'recommendfilter', 'おすすめフィルタ', 'basic' ) do
 	saveconf_recommendfilter
 
 	<<-HTML
